<?php

namespace Drupal\entity_sync\Plugin\EntitySync\FieldTransformer;

use Drupal\entity_sync\FieldTransformer\PluginBase;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Transformer that converts a value according to a map.
 *
 * Supported configuration properties:
 * - map: (array, required) An associative array keyed by the value being
 *   transformed and containing the value that should be given after
 *   transformation.
 * - default_value: (optional, defaults to `NULL`) The value that will be
 *   returned if the value being transformed is not found in the map.
 * - default_value: (mixed, optional, defaults to NULL) The value to use when
 *   the value being transformed is not found in the map.
 *
 * @EntitySyncFieldTransformer(
 *   id = "static_map"
 * )
 */
class StaticMap extends PluginBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'default_value' => NULL,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  protected function validateConfiguration() {
    $this->validateConfigurationRequiredProperties(['map']);
  }

  /**
   * {@inheritdoc}
   */
  protected function transformImportedValue(
    $value,
    \stdClass $remote_entity,
    ContentEntityInterface $local_entity,
    array $field_info,
    array $context
  ) {
    return $this->transformValue($value);
  }

  /**
   * {@inheritdoc}
   */
  protected function transformExportedValue(
    $value,
    ContentEntityInterface $local_entity,
    $remote_entity_id,
    array $field_info,
    array $context
  ) {
    return $this->transformValue($value);
  }

  /**
   * Returns the transformed value.
   *
   * @param mixed $value
   *   The value to transform.
   *
   * @return mixed
   *   The transformed value.
   */
  protected function transformValue($value) {
    if (!isset($this->configuration['map'][$value])) {
      return $this->configuration['default_value'];
    }

    return $this->configuration['map'][$value];
  }

}
